# test to make sure line list data is properly packaged and can be read in correctly

import os
import warnings

import astropy

from ..readers import read_basic_ascii_table, collect_data_files


def test_read_line_lists():
    line_dir = os.path.join("reference_data", "line_lists")
    data_files = collect_data_files(line_dir)
    for f in data_files:
        try:
            t = read_basic_ascii_table(f, names=['wavelength'])
            assert(len(t) > 0)
            assert(len(t.columns) >= 1)
        except astropy.io.ascii.core.InconsistentTableError as e:
            orig_e = e.__class__.__name__
            try:
                t = read_basic_ascii_table(
                    f,
                    reader="ascii.fixed_width",
                    names=['wavelength', 'info'],
                    col_starts=(0, 10),
                    delimiter=' '
                )
                assert(len(t) > 0)
                assert(len(t.columns) >= 1)
            except Exception as e:
                msg = f"Failed to load {f} as a AstroPy Table: {orig_e} {e.__class__.__name__}"
                warnings.warn(msg)



# utility functions for reading packaged data files

import os
import pkg_resources

from astropy.table import Table


def read_basic_ascii_table(table_file, names=None, reader="ascii", **kwargs):
    """
    Try to read a file using AstroPy Table's basic ascii reader
    """
    t = Table.read(table_file, format=reader, names=names, **kwargs)

    return t


def collect_data_files(data_path="", ext=".dat"):
    """
    Walk through data_path, find .dat files, and return list of paths to them.
    """
    data_files = []
    root_dir = pkg_resources.resource_filename("specreduce_data", data_path)
    for root, dirs, files in os.walk(root_dir):
        for name in files:
            if ext in name:
                data_files.append(os.path.join(root, name))

    return data_files



# test to make sure extinction data is properly packaged and can be read in correctly

import os
import warnings

from ..readers import read_basic_ascii_table, collect_data_files


def test_read_extinction():
    ext_dir = os.path.join("reference_data", "extinction")
    data_files = collect_data_files(ext_dir)
    for f in data_files:
        try:
            t = read_basic_ascii_table(f, names=['wavelength', 'extinction'])
            assert(len(t) > 0)
            assert(len(t.columns) == 2)
        except Exception as e:
            msg = f"Failed to load {f} as an AstroPy Table: {e.__class__.__name__}"
            warnings.warn(msg)
